==> okahu_observability-0.4.0-py3-none-any.whl: okahu_apptrace/instrumentation/metamodel/langchain/entities/inference.py <==
from okahu_apptrace.instrumentation.metamodel.langchain import (
    _helper,
)
import os
from okahu_apptrace.instrumentation.common.utils import get_llm_type, resolve_from_alias, extract_provider_name, \
    extract_inference_endpoint

INFERENCE = {
    "type": "inference",
    "attributes": [
        [
            {
                "_comment": "provider type ,name , deployment , inference_endpoint",
                "attribute": "type",
                "accessor": lambda arguments: 'inference.' + (get_llm_type(arguments['instance']) or 'generic')
            },
            {
                "attribute": "provider_name",
                "accessor": lambda arguments: arguments['kwargs'].get('provider_name') or extract_provider_name(
                    arguments['instance'])
            },
            {
                "attribute": "deployment_endpoint",
                "accessor": lambda arguments: resolve_from_alias(arguments['instance'].__dict__,
                                                                 ['engine', 'azure_deployment', 'deployment_name',
                                                                  'deployment_id', 'deployment'])
            },
            {
                "attribute": "inference_endpoint",
                "accessor": lambda arguments: os.environ.get('TRITON_LLM_ENDPOINT') or resolve_from_alias(
                    arguments['instance'].__dict__, ['azure_endpoint', 'api_base']) or extract_inference_endpoint(
                    arguments['instance'])
            },
            {
                "attribute": "endpoint_name",
                "accessor": lambda arguments: resolve_from_alias(arguments['instance'].__dict__, ['endpoint_name'])
            }
        ],
        [
            {
                "_comment": "LLM Model",
                "attribute": "name",
                "accessor": lambda arguments: resolve_from_alias(arguments['instance'].__dict__,
                                                                 ['model', 'model_name', 'endpoint_name'])
            },
            {
                "attribute": "type",
                "accessor": lambda arguments: 'model.llm.' + resolve_from_alias(arguments['instance'].__dict__,
                                                                                ['model', 'model_name',
                                                                                 'endpoint_name'])
            }
        ]
    ],
    "events": [
        {"name": "data.input",
         "attributes": [

             {
                 "_comment": "this is instruction and user query to LLM",
                 "attribute": "input",
                 "accessor": lambda arguments: _helper.extract_messages(arguments['args'])
             }
         ]
         },
        {
            "name": "data.output",
            "attributes": [
                {
                    "_comment": "this is result from LLM",
                    "attribute": "response",
                    "accessor": lambda arguments: _helper.extract_assistant_message(arguments['result'])
                }
            ]
        },
        {
            "name": "metadata",
            "attributes": [
                {
                    "_comment": "this is metadata usage from LLM",
                    "accessor": lambda arguments: _helper.update_span_from_llm_response(arguments['result'],
                                                                                        arguments['instance'])
                }
            ]
        }
    ]
}

==> okahu_observability-0.4.2-py3-none-any.whl: okahu_apptrace/instrumentation/metamodel/langchain/entities/inference.py <==
from okahu_apptrace.instrumentation.metamodel.langchain import (
    _helper,
)
import os
from okahu_apptrace.instrumentation.common.utils import get_llm_type, resolve_from_alias, extract_provider_name, \
    extract_inference_endpoint

INFERENCE = {
    "type": "inference",
    "attributes": [
        [
            {
                "_comment": "provider type ,name , deployment , inference_endpoint",
                "attribute": "type",
                "accessor": lambda arguments: 'inference.' + (get_llm_type(arguments['instance']) or 'generic')
            },
            {
                "attribute": "provider_name",
                "accessor": lambda arguments: arguments['kwargs'].get('provider_name') or extract_provider_name(
                    arguments['instance'])
            },
            {
                "attribute": "deployment_endpoint",
                "accessor": lambda arguments: resolve_from_alias(arguments['instance'].__dict__,
                                                                 ['engine', 'azure_deployment', 'deployment_name',
                                                                  'deployment_id', 'deployment'])
            },
            {
                "attribute": "inference_endpoint",
                "accessor": lambda arguments: os.environ.get('TRITON_LLM_ENDPOINT') or resolve_from_alias(
                    arguments['instance'].__dict__, ['azure_endpoint', 'api_base']) or extract_inference_endpoint(
                    arguments['instance'])
            },
            {
                "attribute": "endpoint_name",
                "accessor": lambda arguments: resolve_from_alias(arguments['instance'].__dict__, ['endpoint_name'])
            }
        ],
        [
            {
                "_comment": "LLM Model",
                "attribute": "name",
                "accessor": lambda arguments: resolve_from_alias(arguments['instance'].__dict__,
                                                                 ['model', 'model_name', 'endpoint_name', 'deployment_name'])
            },
            {
                "attribute": "type",
                "accessor": lambda arguments: 'model.llm.' + resolve_from_alias(arguments['instance'].__dict__,
                                                                                ['model', 'model_name',
                                                                                 'endpoint_name', 'deployment_name'])
            }
        ]
    ],
    "events": [
        {"name": "data.input",
         "attributes": [

             {
                 "_comment": "this is instruction and user query to LLM",
                 "attribute": "input",
                 "accessor": lambda arguments: _helper.extract_messages(arguments['args'])
             }
         ]
         },
        {
            "name": "data.output",
            "attributes": [
                {
                    "_comment": "this is result from LLM",
                    "attribute": "response",
                    "accessor": lambda arguments: _helper.extract_assistant_message(arguments['result'])
                }
            ]
        },
        {
            "name": "metadata",
            "attributes": [
                {
                    "_comment": "this is metadata usage from LLM",
                    "accessor": lambda arguments: _helper.update_span_from_llm_response(arguments['result'],
                                                                                        arguments['instance'])
                }
            ]
        }
    ]
}
